<!DOCTYPE html>
<!--
- Copyright (c) 2020 - 2022 Xilinx, Inc.  All rights reserved.
- Copyright (c) 2022 - 2024 Advanced Micro Devices, Inc.  All rights reserved.
-
- SPDX-License-Identifier: MIT
-->
<html lang="en">

<head>
  <meta charset="utf-8">
  <link rel="icon" href="{{url_for('static',filename='images/icon.png')}}?version={{ versioning }}">
  <link rel="stylesheet" type="text/css" href="{{ url_for('static',filename='styles/common.css') }}?version={{ versioning }}">
  <script type="text/javascript" src="{{ url_for('static', filename='js/jquery.min.js') }}?version={{ versioning }}"></script>
  <script type="text/javascript" src="{{ url_for('static', filename='js/common.js') }}?version={{ versioning }}"></script>
  <script type="text/javascript" src="{{ url_for('static', filename='js/gen_sc.js') }}?version={{ versioning }}"></script>
  <script type="text/javascript" src="{{ url_for('static', filename='js/beam_strings.js') }}?version={{ versioning }}"></script>
  <script type="text/javascript" src="{{ url_for('static', filename='js/strings_append.js') }}?version={{ versioning }}"></script>
  <script type="text/javascript" src="{{ url_for('static', filename='js/gen_bit.js') }}?version={{ versioning }}"></script>
  <script type="text/javascript" src="{{ url_for('static', filename='js/gen_bm.js') }}?version={{ versioning }}"></script>
  <script type="text/javascript" src="{{ url_for('static', filename='js/config_sc.js') }}?version={{ versioning }}"></script>
  <script type="text/javascript" src="{{ url_for('static', filename='js/config_bit.js') }}?version={{ versioning }}"></script>
  <script type="text/javascript" src="{{ url_for('static', filename='js/main.js') }}?version={{ versioning }}"></script>

</head>


<body onload="showloading()" style="margin:0;">

<div id="loader"></div>

<div style="display:none;" id="root" class="animate-bottom bgColor">
  <nav class="navbar navbar-inverse">
    <div class="container-fluid">
      <div class="navbar-header">
        <a class="logo-align align-left"><img
            src="{{url_for('static',filename='images/xilinx.png')}}" alt="logo" height="38" style="padding:10px 10px"/></a>
        <h4 class="app-title" id="app-title-id"></h4>
      </div>
    </div>
  </nav>
  <section class="content_sec ">
    <div class="tab_section ">
      <nav class="tab_sec">
        <ul class="tabitemlist" id="top_menu">
        <li id="ttbbackid" class="tabitem_left hide">❮</li>
        <li class="tabitem_right active">HOME</li>
        <li class="tabitem_right">ABOUT</li>
        <li class="tabitem_right">HELP</li>
        <button class="logs_button" id="getLogs" onclick="getlogs()">Get Logs</button>
        <button class="logs_button" id="exportCSV" onclick="exportCSV()">Export CSV</button>
	</ul>
      </nav>
    </div>
  </section>
    <section id="navSec">
          <div  class="navitem" id="navbar-collapse">
          <nav class="navbar_list" >
            <ul class="tabitemlist" id="top_menu">
                <a class="nav_text" id="navLink"></a>
                <button class="navhide" onclick="hideNavbar()">X</button>
            </ul>
          </nav>
        </div>
      </section>
  <!-- Home Screen-->
  <div class="homelandingrow" id="home_screen_com">
      <div class="app-title"></div>
    <span class="homecolumn" id="railcolumn_com">
    </span>
    <span class="homecolumn2" id="railcolumn_com2">
    </span>
    <span class="homecolumn3" id="tables_com">
        <div>
        <button class="navopt_btn" id="boardsupport" onclick="installboardsetup()" >Install Board Support</button>
        </div>
        <div>
        <button class="navopt_btn" id="testtheboard" onclick=navClick(this.id);>TEST THE BOARD</button>
        </div>
  <!--      <div>
        <button class="navopt_btn" id="linuxprompts" onclick=navClick(this.id)>VERSAL POWER TOOL</button>
        </div> -->
  <!--       <div>
             <button class="navopt_btn" id="cockpit" onclick=navClick(this.id)>VERSAL COCKPIT</button>
         </div> -->
        <div>
             <button class="navopt_btn" id="pmdashboard" onclick=navClick(this.id)>PM DASH BOARD</button>
         </div>
         <div>
             <button class="navopt_btn" id="developusingtools" onclick=navClick(this.id)>DESIGN EXAMPLES</button>
         </div>
    </span>
<!--    <span style="display: block; clear: both;">
        <div>
            <p style="color: red;padding: 20px;font-size: 20px;">*Please Clear Cache or use Private Browser*</p>
        </div>
    </span> -->
  </div>
    <!-- test the board Home Screen-->
  <div class="homelandingrow hide" id="home_screen_db">
      <div class="app-title"></div>
    <span class="homecolumn" id="railcolumn">
      <div class="clock_dashboard">
	<span>
	    <p class="clock_key tempLabel">Versal Junction Temp</p>
	    <div class="tooltipinfo">ⓘ
	    <a class="tooltiptextinfo">Versal Device temperature as read from the Versal internal System Monitor</a>
	    </div>
	</span>
        <!--<p class='clock_value' id='home_board_temp_id'>- °C</p>-->
        <div class="doughnut" id="home_board_temp_id">- °C</div>
      </div> 
        <div>
        <button class="navopt_btn" id="boardsettings" onclick=navClick(this.id);>Board Settings</button>
        </div>
         <div>
        <button class="navopt_btn" id="boardinterfacetest" onclick=navClick(this.id)>Board Interface Test</button>
        </div>
        <div>
        <button class="navopt_btn" id="raucupdate" onclick=navClick(this.id)>Linux File System</button>
        </div>
        <!--<div class="second_dashboard">
        <br><br><br><br><br><br>
                <p class='link_key'>For more information regarding Hardware, Documentation, Tools & IP and Training & Support</p>
        <br><br>
            <button class="prod_page_btn" onclick=openInNewTab("https://www.xilinx.com/products/boards-and-kits/vck190.html#specifications")>View Product Page</button>
      </div>-->
    </span>
    <span class="homecolumn2" id="testboard_home">
    </span>
    <span class="homecolumn3" id="tables">
      <div class="block_dashboard_1" id="db_dashboard" >
          <a class="logo-align align-center" href="#"><img
            src="{{url_for('static',filename='images/versal.png')}}" alt="logo" height="38" style="padding-top:30px; padding-bottom:10px"/></a>
      </div>
        <div class= "block_dashboard_1" id="detectBootModeID">
           <p class='details_info'> <b>Boot Mode:</b></p>
          <!--<p class='details_info'>JTAG : [0000]</p>
          <p class='details_info'>Boot Module : [0010]</p>
          <p class='details_info'>SD1_3.0 : [1110]</p>-->

      </div>
        <div class="block_dashboard_1" id="detectPDI">
            <p class='details_info'> <b>Upload PDI:</b></p>
        </div>
    </span>
  </div>
<!-- Help Screen-->
  <div class="homelandingrow hide" id="help_screen">
      <div class="app-title"></div>
    <span class="" id="">
    </span>
  </div>
<!-- About Screen-->
    <div class="homelandingrow hide" id="about_screen">
      <div class="app-title"></div>
    <span class="" id="railcolumn">

    </span>
  </div>
          <!-- linux prompt screen-->
  <div class="homelandingrow hide" id="linuxprompt_screen">
      <div class="app-title"></div>
    <span class="" id="railcolumn">
    </span>
  </div>

        <!-- Demos and Design Screen-->
  <div class="homelandingrow hide" id="dnd_screen">
      <div class="app-title"></div>
    <span class="" id="railcolumn">
    </span>
  </div>

          <!-- Tools screen-->
  <div class="homelandingrow hide" id="tools_screen">
      <div class="app-title"></div>
  </div>


	<!-- Others -->
  <div class="homelandingrow hide" id="boardseettings_screen">
      <div class="app-title"></div>
    <span class="" id="railcolumn">
      <!--                -->

<div class="boardtests-pagecontent">
          <div class="sidemenu">
            <ul id = "boardtestdiv" class="menuitems">
<!--              <li class="active">Clocks</li>-->
<!--              <li>Voltages</li>-->
<!--              <li>Power</li>-->
            </ul>
          </div>
          <div class="preview_body">
            <div class="tabsection" id="bsettings_subtabs">
              <div class="content-body" id="clocksSubTabs">
<!--                <div class=" ">-->
<!--                    <nav class="">-->
<!--                        <ul class="subtabitemlist" >-->
<!--                            <li class="tab_subitem active">Set</li>-->
<!--                            <li class="tab_subitem">Get</li>-->
<!--                            <li class="tab_subitem">Restore to Default</li>-->
<!--                        </ul>-->
<!--                    </nav>-->
<!--                </div>-->
<!--                <div id="clock_set_div">-->
<!--                <table id="boardsettings" class="boardsettings_table" style="width:100%">-->
<!--                    <tbody class="table_body" id="clocksSet">-->
<!--                        <tr>-->
<!--                            <td><input type="checkbox"></td>-->
<!--                            <td>zSFP Si570 Frequency</td>-->
<!--                          <td><input type="text"> </td>-->
<!--                            <td>(Between 10 and 810 MHz)</td>-->
<!--                            <td><button type="button">Set Frequency</button></td>-->
<!--                        </tr>-->
<!--                                <tr>-->
<!--                            <td><input type="checkbox"></td>-->
<!--                            <td>zSFP DIMM1 Frequency</td>-->
<!--                          <td><input type="text"> </td>-->
<!--                            <td>(Between 10 and 810 MHz)</td>-->
<!--                            <td><button type="button" >Set Frequency</button></td>-->
<!--                        </tr>-->
<!--                    </tbody>-->
<!--                </table>-->
<!--            </div>-->
                  <div id="clock_get_div" class="hide">
                <table id="" class="boardsettings_table" style="width:100%">
                    <tbody class="table_body" id="clocksget">
                        <tr>
                            <td><input type="checkbox"></td>
                            <td>zSFP Si570 Frequency</td>
                                                      <td><input type="text"> </td>


                            <td><button type="button">Get Frequency</button></td>
                        </tr>
                                <tr>
                            <td><input type="checkbox"></td>
                            <td>DIMM1 Si570 Frequency</td>
                          <td><input type="text"> </td>
                            <td><button type="button" >Get Frequency</button></td>
                        </tr>
                    </tbody>
                </table>
            </div>
                  <div id="clock_restore_div" class="hide">
                <table id="" class="boardsettings_table" style="width:100%">
                    <tbody class="table_body" id="clocksreset">
                        <tr>
                            <td><input type="checkbox"></td>
                            <td>zSFP Si570 Frequency</td>
<!--                          <td><input type="text"> </td>-->
<!--                            <td>(Between 10 and 810 MHz)</td>-->
                            <td><button type="button">Restore to Default</button></td>
                        </tr>
                                <tr>
                            <td><input type="checkbox"></td>
                            <td>zSFP DIMM1 Frequency</td>
<!--                          <td><input type="text"> </td>-->
<!--                            <td>(Between 10 and 810 MHz)</td>-->
                            <td><button type="button" >Restore to Default</button></td>
                        </tr>
                    </tbody>
                </table>
            </div>
                <div id="test2view" class="tabsection hide">
                <h4 class="preview_title">Clock test</h4>
                <div class="content-body" id="test2viewcontent">

                  Clock test
                </div>
            </div>
                                <div id="test3view" class="tabsection hide">
                <h4 class="preview_title">GT lopback test</h4>
                <div class="content-body" id="test3viewcontent">
                  GT lopback test
                </div>
            </div>
                                <div id="test4view" class="tabsection hide">
                <h4 class="preview_title">FMCP Test</h4>
                <div class="content-body" id="test4viewcontent">
                  FMCP Test
                </div>
            </div>
                                <div id="test5view" class="tabsection hide">
                <h4 class="preview_title">PCIe loopback test</h4>
                <div class="content-body" id="test5viewcontent">
                  PCIe loopback test
                </div>
            </div>
                                <div id="test6view" class="tabsection hide">
                <h4 class="preview_title">HDMI test</h4>
                <div class="content-body" id="test6viewcontent"></div>
            </div>
                                <div id="test7view" class="tabsection hide">
                <h4 class="preview_title">MIO test</h4>
                <div class="content-body" id="test7viewcontent">
                  MIO test
                </div>
            </div>
                                <div id="test8view" class="tabsection hide">
                <h4 class="preview_title">Memory test</h4>
                <div class="content-body" id="test8viewcontent">
                  Memory test
                </div>
            </div>
              </div>
                <div class="content-body hide" id="voltagesubtabs">
                <table id="" class="boardsettings_table" style="width:100%">
                    <tbody class="table_body" id="clocksSet">
                        <tr>
                            <td><input type="checkbox"></td>
                            <td>zSFP Si570 Frequency</td>
                          <td><input type="text"> </td>
                            <td>(voltage 10 and 810 MHz)</td>
                            <td><button type="button">Set Frequency</button></td>
                        </tr>
                                <tr>
                            <td><input type="checkbox"></td>
                            <td>zSFP DIMM1 Frequency</td>
                          <td><input type="text"> </td>
                            <td>(Between 10 and 810 MHz)</td>
                            <td><button type="button" >Set Frequency</button></td>
                        </tr>
                    </tbody>
                </table>

                  <div id="" class="hide">
                <table id="" class="boardsettings_table" style="width:100%">
                    <tbody class="table_body" id="">
                        <tr>
                            <td><input type="checkbox"></td>
                            <td>zSFP Si570 Frequency</td>
<!--                          <td><input type="text"> </td>-->
<!--                            <td>(Between 10 and 810 MHz)</td>-->
                            <td><button type="button">Restore to Default</button></td>
                        </tr>
                                <tr>
                            <td><input type="checkbox"></td>
                            <td>zSFP DIMM1 Frequency</td>
<!--                          <td><input type="text"> </td>-->
<!--                            <td>(Between 10 and 810 MHz)</td>-->
                            <td><button type="button" >Restore to Default</button></td>
                        </tr>
                    </tbody>
                </table>
            </div>
                <div id="" class="tabsection hide">
                <h4 class="preview_title">Clock test</h4>
                <div class="content-body" id="">

                  Clock test
                </div>
            </div>
                                <div id="test3view" class="tabsection hide">
                <h4 class="preview_title">GT lopback test</h4>
                <div class="content-body" id="test3viewcontent">
                  GT lopback test
                </div>
            </div>
                                <div id="test4view" class="tabsection hide">
                <h4 class="preview_title">FMCP Test</h4>
                <div class="content-body" id="test4viewcontent">
                  FMCP Test
                </div>
            </div>
                                <div id="test5view" class="tabsection hide">
                <h4 class="preview_title">PCIe loopback test</h4>
                <div class="content-body" id="test5viewcontent">
                  PCIe loopback test
                </div>
            </div>
                                <div id="test6view" class="tabsection hide">
                <h4 class="preview_title">HDMI test</h4>
                <div class="content-body" id="test6viewcontent"></div>
            </div>
                                <div id="test7view" class="tabsection hide">
                <h4 class="preview_title">MIO test</h4>
                <div class="content-body" id="test7viewcontent">
                  MIO test
                </div>
            </div>
                                <div id="test8view" class="tabsection hide">
                <h4 class="preview_title">Memory test</h4>
                <div class="content-body" id="test8viewcontent">
                  Memory test
                </div>
            </div>
              </div>
            </div>
          </div>
        </div>
<!--       dfaf     -->
    </span>
  </div>
    <div class="homelandingrow hide" id="testandebug_screen">
      <div class="app-title"></div>
    <span class="" id="railcolumn">
<!--    another tab            -->
        <div id="bit_tab_screen">

            </div>
<!--       dfaf     -->
    </span>
  </div>

<div class="homelandingrow hide" id="raucupdate_screen">
    <div class="app-title">Linux File System</div>
    <div id="rauc_update_screen">

    </div>
</div>
  <section class="content_sec ">
    <div class="tab_section footer">
      <nav class="tab_sec ">
        <ul class="tabitemlist " id="bottom_menu">
<!--          <li class="tabitem">Demos & Design</li>-->
<!--          <li class="tabitem">Board Settings</li>-->
<!--          <li class="tabitem">Test & Debug</li>-->
          <div id="versionLabel">V 0.0</div>
        </ul>
      </nav>
    </div>
  </section>

</div>
<div id="popform" class="popup-background"></div>
<div id="apiloadingdiv" class="apiloadin"><div id="loaderspin"></div></div>

</body>
</html>
